@@ -136,6 +136,11 @@ def main():
                         dest = 'PAGE',
                         help = 'the page, of specified length, from the total collection, to return in a report. (Ignored if items are specified.)',
                         default = None)
+    parser.add_argument('--prepared',
+                        dest = 'PREPARED',
+                        help = 'lists the set of items that are know to this program and are ready to be submitted for processing by the specified configuration/version',
+                        action = 'store_true',
+                        default = False)
     parser.add_argument('-p',
                         '--processed',
                         dest = 'PROCESSED',
@@ -302,6 +307,12 @@ def main():
             Display.info(config, version, report)
             run_default = False
 
+        if options.PREPARED:
+            verify_args(config, options.VERSION)
+            report, version = psquared.get_report(config, options.VERSION, 'prepared', page = options.PAGE, length = options.LENGTH, items = optional_items(items))
+            Display.info(config, version, report)
+            run_default = False
+
         if options.PROCESSED:
             verify_args(config, options.VERSION)
             report, version = psquared.get_report(config, options.VERSION, 'processed', page = options.PAGE, length = options.LENGTH, items = optional_items(items))
